    // Read control dictionary
    IOdictionary wpcRASDict
    (
        IOobject
        (
            "wpcRASDict",
            runTime.system(),
            mesh,
            IOobject::MUST_READ,
            IOobject::NO_WRITE
        )
    );

    const dimensionedScalar referenceDynamicPressure
    (
        wpcRASDict.lookup("referenceDynamicPressure")
    );

    Info << "Reference Dynamic Pressure = " << referenceDynamicPressure << endl; 
    
    const vector referenceStaticPressureLocation
    (
        wpcRASDict.lookup("referenceStaticPressureLocation")
    );

    Info << "Reference Static Pressure Location = " <<
        referenceStaticPressureLocation << endl; 

    // make octree  data cells
    const cellList& cells = mesh.cells();
    const pointField& points = mesh.points();

    treeBoundBox meshBb(points);

    scalar typDim = meshBb.avgDim()/(2.0*pow(cells.size(), 1.0/3.0));

    treeBoundBox shiftedBb
    (
        meshBb.min() - vector(typDim, typDim, typDim),
        meshBb.max() + vector(typDim, typDim, typDim)
    );

    octreeDataCell shapes(mesh);

    octree<octreeDataCell> oc
    (
        shiftedBb,  // overall bounding box
        shapes,     // all information needed to do checks on cells
        1,          // min. levels
        10.0,       // max. size of leaves
        10.0        // maximum ratio of cubes v.s. cells
    );

    label cellRefPstat = oc.find(referenceStaticPressureLocation);
    if (cellRefPstat<0)
    {
        Info  << "Cannot find cell at "
            << referenceStaticPressureLocation
            << endl;
    }

    Info << "Actual location (cell centre) for reference static pressure = " << 
        mesh.C()[cellRefPstat] << endl; 
